@@ -217,10 +217,11 @@ class LockdownClient(object):
     def set_locale(self, locale: str):
         self.set_value(locale, key='Locale', domain='com.apple.international')
 
-    def generate_host_id(self):
+    @staticmethod
+    def generate_host_id() -> str:
         hostname = platform.node()
-        hostid = uuid.uuid3(uuid.NAMESPACE_DNS, hostname)
-        return str(hostid).upper()
+        host_id = uuid.uuid3(uuid.NAMESPACE_DNS, hostname)
+        return str(host_id).upper()
 
     @reconnect_on_remote_close
     def enter_recovery(self):
@@ -246,14 +247,6 @@ class LockdownClient(object):
             return None
         return pair_record
 
-    def get_usbmux_pairing_record(self):
-        mux = usbmux.create_mux()
-        if not isinstance(mux, PlistMuxConnection):
-            return None
-        pairing_record = mux.get_pair_record(self.udid)
-        mux.close()
-        return pairing_record
-
     def get_local_pairing_record(self):
         self.logger.debug('Looking for pymobiledevice3 pairing record')
         path = HOMEFOLDER / f'{self.identifier}.plist'
@@ -266,10 +259,13 @@ class LockdownClient(object):
         pair_record = self.get_itunes_pairing_record()
         if pair_record is not None:
             self.logger.info(f'Using iTunes pair record: {self.identifier}.plist')
-        elif Version(self.ios_version) >= Version('13.0'):
-            pair_record = self.get_usbmux_pairing_record()
+
+        mux = usbmux.create_mux()
+        if isinstance(mux, PlistMuxConnection):
+            pair_record = mux.get_pair_record(self.udid)
         else:
             pair_record = self.get_local_pairing_record()
+        mux.close()
 
         if pair_record is None:
             return False
